---
title: useThrelte
---

# useThrelte

This hook lets you consume the state of the `<Canvas>` component which contains the renderer, camera, scene and so on.  
It is recommended to set the camera via the property `setCamera` of the [root context](/docs/hooks/useThrelteRoot).

```ts
const {
  size, // Readable<Size>
  pointer, // Writable<Vector2>
  pointerOverCanvas, // Writable<boolean>
  clock, // Clock
  camera, // Writable<Camera>
  scene, // Scene
  renderer, // WebGLRenderer
  composer, // EffectComposer
  invalidate, // (debugFrameloopMessage?: string) => void
  advance // () => void
} = useThrelte()
```

If the [frameloop is set to `'demand'`](/docs/components/canvas) and you are manually editing objects or materials, be sure to invalidate the current frame to request a rerender:

```ts
const { invalidate } = useThrelte()

invalidate()

// Optionally provide a debugFrameloopMessage to debug the frame loop
invalidate('changed material color')
```

If the [frameloop is set to `'never'`](/docs/components/canvas) you must manually advance the frameloop to request a new render:

```ts
const { advance } = useThrelte()

advance()
```

:::admonition type="tip"
This context is also available as the first argument of the callback of the [useFrame hook](/docs/hooks/useFrame)!
:::
